@@ -10,7 +10,7 @@ void Remailer::copySignature(ostream &out, string const &boundary)
             "\n";
 
     ifstream sig;
-    Exception::open(sig, d_signatureName);
+    LogException::open(sig, d_signatureName);
 
     d_log << level(LOGDEBUG) << "Signature expected on " << d_signatureName <<
                                                                     '\n';
@@ -34,8 +34,10 @@ void Remailer::copySignature(ostream &out, string const &boundary)
         (d_sigRequired == SIGNATURE_FOUND && 
             sigStruct.sigType == NO_SIGNATURE)
     )
-        d_log << level(LOGDEFAULT) << "[Fatal] "
-                "Bad or missing signature in " << d_orgName << '\n' << FATAL;
+        throw LogException() << "bad or missing signature in " << 
+                d_contentsName << '\n';
+
+    d_log << level(LOGDEBUG) << "Signature check successfully passed\n";
 
     out << '\n' <<
             boundary << '\n';
@@ -43,3 +45,4 @@ void Remailer::copySignature(ostream &out, string const &boundary)
 
 
 
+
