@@ -5,6 +5,7 @@
 void Remailer::copyToBoundary(string const &destName, istream &in)
 {
     ofstream out;
+    LogException::open(out, destName);
     
-    copyToBoundary(open(out, destName, DONT_UNLINK), in);
+    copyToBoundary(out, in);
 }
