@@ -5,7 +5,7 @@ void Remailer::findBoundary(IOContext &io)
     while (!hasBoundary(io.line, "multipart/signed"))
     {
         if (!getline(io.decrypted, io.line))
-            d_log << level(LOGDEFAULT) << 
-                        "multipart/signed: no boundary found\n" << FATAL;
+            throw LogException() << 
+                    "multipart/signed: no boundary found\n";
     }
 }
