@@ -1,31 +1,7 @@
 #include "remailer.ih"
 
-    // Third format mentioned in the man-page
-void Remailer::multipartSigned(IOContext &io)
-{
-    findBoundary(io);
-
-    ostream null(0);
-    copyToBoundary(null, io.decrypted);  // skip all headers
-
-    copyToBoundary(d_multipartSignedDataName, io.decrypted);
-
-    ostringstream command;
-    command << "--verify " << 
-            d_decryptedName << " " << d_multipartSignedDataName;
-
-    gpg(command.str(), d_signatureName);
-
-    copySignature(io.toReencrypt, d_boundary);
-
-    ifstream data;
-    Exception::open(data, d_multipartSignedDataName);
-
-    io.toReencrypt << data.rdbuf();
-}
-
-
-// Format of the decrypted PGP part:
+// Format of the decrypted PGP part, having a detached signature 
+// (near line 457 in gpg-remailer(1)): 
 // ----------------------------------------------------------------------
 // Content-Type: multipart/signed; micalg=pgp-sha1; \ (line continues)
 //                                      protocol="application/pgp-signature";
@@ -47,3 +23,25 @@ void Remailer::multipartSigned(IOContext &io)
 // 
 // --=-TNwuMvq+TfajHhvqBuO7--
 // ----------------------------------------------------------------------
+
+void Remailer::multipartSigned(IOContext &io)
+{
+    d_log << level(LOGDEBUG) << "Multipart-Signed e-mail received\n";
+
+    findBoundary(io);
+
+    ostream null(0);
+
+    copyToBoundary(null, io.decrypted);  // skip all headers
+
+    copyToBoundary(d_multipartSignedDataName, io.decrypted);
+
+    d_gpg.verify(d_decryptedName, d_multipartSignedDataName, d_signatureName);
+
+    copySignature(io.toReencrypt, d_boundary);
+
+    ifstream data;
+    LogException::open(data, d_multipartSignedDataName);
+
+    io.toReencrypt << data.rdbuf();
+}
